@@ -2,36 +2,13 @@ package Data::Record::Serialize::Sink::stream;
 
 # ABSTRACT: output encoded data to a stream.
 
-
 use Moo::Role;
 
-use Data::Record::Serialize::Error { errors => [ '::create' ] }, -all;
-
-our $VERSION = '0.34';
-
-use IO::File;
+our $VERSION = '1.00';
 
 use namespace::clean;
 
-has output => (
-    is      => 'ro',
-);
-
-has fh => (
-    is => 'lazy',
-    builder => sub {
-        my $self = shift;
-        return ( ! defined $self->output || $self->output eq '-' )
-          ? \*STDOUT
-          : ( IO::File->new( $self->output, 'w' )
-              or error( '::create', "unable to create @{[ $self->output ]}" ) );
-    },
-   clearer => 1,
-   predicate => 1,
-);
-
-
-
+with 'Data::Record::Serialize::Role::Sink::Stream';
 
 
 
@@ -41,18 +18,6 @@ has fh => (
 sub print { shift->fh->print( @_ ) }
 sub say   { shift->fh->say( @_ ) }
 
-sub close {
-    my ( $self, $in_global_destruction ) = @_;
-
-    # don't bother closing the FH; it'll be done on its own.
-    return if $in_global_destruction;
-
-    # fh is lazy, so the object may close without every using it, so
-    # don't inadvertently create it.
-    $self->fh->close if $self->has_fh;
-    $self->clear_fh;
-}
-
 with 'Data::Record::Serialize::Role::Sink';
 
 1;
@@ -79,7 +44,7 @@ Data::Record::Serialize::Sink::stream - output encoded data to a stream.
 
 =head1 VERSION
 
-version 0.34
+version 1.00
 
 =head1 SYNOPSIS
 
@@ -98,9 +63,6 @@ It performs the L<Data::Record::Serialize::Role::Sink> role.
 
 =for Pod::Coverage print
  say
- close
- has_fh
- clear_fh
 
 =head1 INTERFACE
 
